%%  Read in tab-delimited data using load.
	clear all
    close all
	load lake_pt.dat

%%  Extract the pressure (column 1) and temperature (column 2).
	p = lake_pt(:,1);
	t = lake_pt(:,2);

%  How many data points are there?
	m = length(p)
	dim = size(p)
	m = dim(1,1)
	n = dim(1,2)

%%  What does the data look like?
figure(1)	
plot(p,t)
xlabel('pressao')
ylabel('temperatura')

%%  Convert the temperature to density.
	rho = 999.842594 + 6.793952e-2*t - 9.095290e-3*t.^2 ...
		   + 1.001685e-4*t.^3 - 1.120083e-6*t.^4 + 6.536332e-9*t.^5;

%%  Convert the pressures to depths.
	g = 9.81;     % Acceleration of gravity.
	z(1) = p(1)*1000 / (rho(1)*g);
	for i = 2:m, 
		z(i) = z(i-1) + (p(i) - p(i-1))*1000 / (rho(i)*g);
	end
	
%%  Plot the data.
	figure(2)
    plot(t,z,(rho-1000),z,'k-')
	set(gca,'YDir','reverse')
	set(gca,'YGrid','on')	
	set(gca,'XGrid','on')
	set(gca,'Box','on')
	axis([-5 25 0 60])
	title('Lake temperature and density profile')
	xlabel('Temperature  [deg C] and Density [kg/m-1000kg/m]')
	ylabel('Depth  [m]')
	legend ('Temperature', 'Density-1000kg/m')
    

%  Or using subplot.
	figure(3)
	subplot(1,2,1)
   	plot(t,z,'k-')
		set(gca,'YDir','reverse')
		axis([0 25 0 60])
		title('Lake temperature profile')
		xlabel('Temperature  [deg C]')
		ylabel('Depth  [m]')
	subplot(1,2,2)
		plot(rho,z,'k-')
		set(gca,'YDir','reverse')
		axis([997 1000 0 60])
		title('Lake density profile')
		xlabel('Density  [kg/m^3]')
		ylabel('Depth  [m]')

   
%%  computing dT/dz
spacing(1)=abs(z(1));
for i=2:max(size(z))
    spacing(i)=abs(z(i))-(abs(z(i-1)));
end
dTs = gradient(t, spacing);
dT=gradient(t);
dT2=gradient(dTs, spacing);

%% plots of gradients for raw data
figure(4)
	subplot(1,4,1)
   	plot(t,z,'k-')
		set(gca,'YDir','reverse')
		axis([0 25 0 60])
		title('Lake temperature profile')
		xlabel('Temperature  [deg C]')
		ylabel('Depth  [m]')
	subplot(1,4,2)
		plot(dT,z,'k-')
		set(gca,'YDir','reverse')
        axis([-1 1 0 60])
		title('first gradient - equidistant')
		xlabel('C/m')
		ylabel('Depth  [m]')
    subplot(1,4,3)
		plot(dTs,z,'k-')
		set(gca,'YDir','reverse')
        axis([-1000 1000 0 60])
		title('first gradient - spacing')
		xlabel('C/m')
		ylabel('Depth  [m]')
	subplot(1,4,4)
		plot(dT2,z,'k-')
		set(gca,'YDir','reverse')
        axis([-5000 5000 0 60])
		title('second gradient - spacing')
		xlabel('C^2/m^2')
		ylabel('Depth  [m]')
        
   %% better: smoothing data before
   t2 = smooth(z',t,0.1,'rloess');
   figure(5)
   plot(t,z,'.', t2,z,'r')
		set(gca,'YDir','reverse')
        axis([0 25 0 60])
		title('smoothed data')
		xlabel('C')
		ylabel('Depth  [m]')
        legend('original data points', 'smoothed','Location','SE')
        
        
dTs = gradient(t2, spacing);
dT=gradient(t2);
dT2=gradient(dT);

%% finding thermocline
    thermo=find(dT==min(dT))
    thermosmoothed=z(thermo)
      figure(6)
	subplot(1,4,1)
   	plot(t2,z,'k-')
		set(gca,'YDir','reverse')
		axis([0 25 0 60])
		title('Lake temperature profile')
		xlabel('Temperature  [deg C]')
		ylabel('Depth  [m]')
        hold on
        plot(z(thermo),'*')
        hold off
	subplot(1,4,2)
		plot(dT,z,'k-')
		set(gca,'YDir','reverse')
        axis([-0.2 0.2 0 60])
		title('first gradient - equidistant')
		xlabel('C/m')
		ylabel('Depth  [m]')
        hold on
        plot(z(thermo),'*')
        hold off
    subplot(1,4,3)
		plot(dTs,z,'k-')
		set(gca,'YDir','reverse')
        axis([-50 50 0 60])
		title('first gradient - spacing')
		xlabel('C/m')
		ylabel('Depth  [m]')
        hold on
        plot(z(thermo),'*')
        hold off
	subplot(1,4,4)
		plot(dT2,z,'k-')
		set(gca,'YDir','reverse')
        axis([-0.05 0.05 0 60])
		title('second gradient - equidistant')
		xlabel('C^2/m^2')
		ylabel('Depth  [m]')
        hold on
        plot(z(thermo),'*')
        hold off
      
        
        %% fitting polynomia
        poli=polyfit(z',t,7);
        depth=0:1:60;
        t3=polyval(poli,depth);
        dT=gradient(t3);
        dT2=gradient(dT);
        
        figure(7)
        plot(t,z,'.', t3,depth,'r')
		set(gca,'YDir','reverse')
        axis([0 25 0 60])
		title('polynomial fit')
		xlabel('C')
		ylabel('Depth  [m]')
        legend('original data points', 'polynomial','Location','SE')
        
        % finding thermocline
        thermo=find(dT==min(dT))
        thermopoly=depth(thermo)
        figure(8)
        subplot(1,3,1)
        plot(t3,depth,'k-')
		set(gca,'YDir','reverse')
		axis([0 25 0 60])
		title('Lake temperature profile')
		xlabel('Temperature  [deg C]')
		ylabel('Depth  [m]')
        hold on
        plot(depth(thermo),'*')
        hold off
	subplot(1,3,2)
		plot(dT,depth,'k-')
		set(gca,'YDir','reverse')
        axis([-2 2 0 60])
		title('first gradient - equidistant')
		xlabel('C/m')
		ylabel('Depth  [m]')
        hold on
        plot(depth(thermo),'*')
        hold off
    subplot(1,3,3)
		plot(dT2,depth,'k-')
		set(gca,'YDir','reverse')
        axis([-.5 .5 0 60])
		title('second gradient - equidistant')
		xlabel('C^2/m^2')
		ylabel('Depth  [m]')
        hold on
        plot(depth(thermo),'*')
        hold off
	
        
%% fitting spline
        t4=spline(z,t,depth);
        dT=gradient(t4);
        dT2=gradient(dT);
        
        figure(9)
        plot(t,z,'.', t4,depth,'r')
		set(gca,'YDir','reverse')
        axis([0 25 0 60])
		title('smoothed data')
		xlabel('C')
		ylabel('Depth  [m]')
        legend('original data points', 'spline','Location','SE')
        
        % finding thermocline
        thermo=find(dT==min(dT))
        thermospline=depth(thermo)
        figure(10)
        subplot(1,3,1)
        plot(t4,depth,'k-')
		set(gca,'YDir','reverse')
		axis([0 25 0 60])
		title('Lake temperature profile')
		xlabel('Temperature  [deg C]')
		ylabel('Depth  [m]')
        hold on
        plot(depth(thermo),'*')
        hold off
	subplot(1,3,2)
		plot(dT,depth,'k-')
		set(gca,'YDir','reverse')
        %axis([-1 1 0 60])
		title('first gradient - equidistant')
		xlabel('C/m')
		ylabel('Depth  [m]')
        hold on
        plot(depth(thermo),'*')
        hold off
    subplot(1,3,3)
		plot(dT2,depth,'k-')
		set(gca,'YDir','reverse')
        axis([-1 1 0 60])
		title('second gradient - equidistant')
		xlabel('C^2/m^2')
		ylabel('Depth  [m]')
        hold on
        plot(depth(thermo),'*')
        hold off